@@ -47,7 +47,7 @@
 #include <KIO/FileCopyJob>
 #include <KIO/StatJob>
 #include <KJobWidgets>
-#include <KMime/KMimeMessage>
+#include <KMime/Message>
 
 #include <KActionCollection>
 #include <KActionMenu>
@@ -215,6 +215,7 @@ void ActionManager::createCalendarAkonadi()
     mCalendarView->readSettings();
 
     // connect(calendar().data(), &Akonadi::ETMCalendar::calendarChanged, mCalendarView, &CalendarView::resourcesChanged);
+    connect(calendar().data(), &Akonadi::ETMCalendar::calendarSelectionEdited, this, &ActionManager::writeSettings);
     connect(mCalendarView, &CalendarView::configChanged, this, &ActionManager::updateConfig);
 
     calendar()->setOwner(KCalendarCore::Person(CalendarSupport::KCalPrefs::instance()->fullName(), CalendarSupport::KCalPrefs::instance()->email()));
@@ -240,7 +241,7 @@ void ActionManager::initActions()
     //~~~~~~~~~~~~~~~~~~~~~~~~ IMPORT / EXPORT ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     /** Import Action **/
     // TODO: Icon
-    mImportAction = new QAction(i18n("Import &Calendar..."), this);
+    mImportAction = new QAction(i18nc("@action", "Import &Calendar…"), this);
     mImportAction->setStatusTip(i18nc("@info:status", "Import a calendar"));
     mImportAction->setToolTip(i18nc("@info:tooltip", "Import an iCalendar or vCalendar file"));
     mImportAction->setWhatsThis(i18nc("@info:whatsthis",
@@ -250,7 +251,7 @@ void ActionManager::initActions()
     connect(mImportAction, &QAction::triggered, this, &ActionManager::file_import);
 
     /** Get Hot New Stuff Action **/
-    auto knsAction = new KNSWidgets::Action(i18n("Get New Calendars..."), QStringLiteral("korganizer.knsrc"), this);
+    auto knsAction = new KNSWidgets::Action(i18n("Get New Calendars…"), QStringLiteral("korganizer.knsrc"), this);
     knsAction->setStatusTip(i18nc("@info:status", "Load a calendar from \"Get Hot New Stuff\""));
     knsAction->setToolTip(i18nc("@info:tooltip", "Search \"Get Hot New Stuff\" for calendars to import"));
     knsAction->setWhatsThis(i18nc("@info:whatsthis",
@@ -302,7 +303,7 @@ void ActionManager::initActions()
     QAction *action = nullptr;
     /** Export Action **/
     // TODO: Icon
-    action = new QAction(i18n("Export as &iCalendar..."), this);
+    action = new QAction(i18nc("@action", "Export as &iCalendar…"), this);
     action->setStatusTip(i18nc("@info:status", "Export calendar to file"));
     action->setToolTip(i18nc("@info:tooltip", "Export your calendar to an iCalendar file"));
     action->setWhatsThis(i18nc("@info:whatsthis", "Allows you to export your entire calendar collection to one iCalendar file."));
@@ -311,7 +312,7 @@ void ActionManager::initActions()
 
     /** Archive Action **/
     // TODO: Icon
-    action = new QAction(i18n("Archive O&ld Incidences..."), this);
+    action = new QAction(i18nc("@action", "Archive O&ld Incidences…"), this);
     action->setStatusTip(i18nc("@info:status", "Archive events and to-dos to a file"));
     action->setToolTip(i18nc("@info:tooltip", "Archive old events and to-dos to an iCalendar file"));
     action->setWhatsThis(i18nc("@info:whatsthis",
@@ -323,7 +324,7 @@ void ActionManager::initActions()
 
     /** Purge Todos Action **/
     // TODO: Icon
-    action = new QAction(i18n("Pur&ge Completed To-dos"), mACollection);
+    action = new QAction(i18nc("@action", "Pur&ge Completed To-dos"), mACollection);
     action->setStatusTip(i18nc("@info:status", "Purge completed to-dos"));
     action->setToolTip(i18nc("@info:tooltip", "Remove completed to-dos from your calendar"));
     action->setWhatsThis(i18nc("@info:whatsthis",
@@ -457,7 +458,7 @@ void ActionManager::initActions()
 
     /** Refresh Action **/
     // TODO: icon
-    action = new QAction(i18n("&Refresh"), this);
+    action = new QAction(i18nc("@action", "&Refresh"), this);
     action->setStatusTip(i18nc("@info:status", "Refresh"));
     action->setToolTip(i18nc("@info:tooltip", "Refresh the display"));
     action->setWhatsThis(i18nc("@info:whatsthis",
@@ -563,7 +564,7 @@ void ActionManager::initActions()
 
     /************************** Actions MENU *********************************/
     /** New Event Action **/
-    mNewEventAction = new QAction(QIcon::fromTheme(QStringLiteral("appointment-new")), i18n("New E&vent..."), this);
+    mNewEventAction = new QAction(QIcon::fromTheme(QStringLiteral("appointment-new")), i18n("New E&vent…"), this);
     mNewEventAction->setStatusTip(i18nc("@info:status", "Create a new Event"));
     mNewEventAction->setToolTip(i18nc("@info:tooltip", "Create a new Event"));
     mNewEventAction->setWhatsThis(i18nc("@info:whatsthis",
@@ -573,7 +574,7 @@ void ActionManager::initActions()
     connect(mNewEventAction, &QAction::triggered, this, &ActionManager::slotNewEvent);
 
     /** New To-do Action **/
-    mNewTodoAction = new QAction(QIcon::fromTheme(QStringLiteral("task-new")), i18n("New &To-do..."), this);
+    mNewTodoAction = new QAction(QIcon::fromTheme(QStringLiteral("task-new")), i18n("New &To-do…"), this);
     mNewTodoAction->setStatusTip(i18nc("@info:status", "Create a new To-do"));
     mNewTodoAction->setToolTip(i18nc("@info:tooltip", "Create a new To-do"));
     mNewTodoAction->setWhatsThis(i18nc("@info:whatsthis",
@@ -584,7 +585,7 @@ void ActionManager::initActions()
 
     /** New Sub-To-do Action **/
     // TODO: icon
-    mNewSubtodoAction = new QAction(i18n("New Su&b-to-do..."), this);
+    mNewSubtodoAction = new QAction(i18nc("@action", "New Su&b-to-do…"), this);
     // TODO: statustip, tooltip, whatsthis
     mACollection->addAction(QStringLiteral("new_subtodo"), mNewSubtodoAction);
     connect(mNewSubtodoAction, &QAction::triggered, this, &ActionManager::slotNewSubTodo);
@@ -592,7 +593,7 @@ void ActionManager::initActions()
     connect(mCalendarView, &CalendarView::todoSelected, mNewSubtodoAction, &QAction::setEnabled);
 
     /** New Journal Action **/
-    mNewJournalAction = new QAction(QIcon::fromTheme(QStringLiteral("journal-new")), i18n("New &Journal..."), this);
+    mNewJournalAction = new QAction(QIcon::fromTheme(QStringLiteral("journal-new")), i18n("New &Journal…"), this);
     mNewJournalAction->setStatusTip(i18nc("@info:status", "Create a new Journal"));
     mNewJournalAction->setToolTip(i18nc("@info:tooltip", "Create a new Journal"));
     mNewJournalAction->setWhatsThis(i18nc("@info:whatsthis", "Starts a dialog that allows you to create a new Journal entry."));
@@ -600,7 +601,7 @@ void ActionManager::initActions()
     connect(mNewJournalAction, &QAction::triggered, this, &ActionManager::slotNewJournal);
 
     /** Configure Current View Action **/
-    mConfigureViewAction = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure View..."), this);
+    mConfigureViewAction = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure View…"), this);
     mConfigureViewAction->setIconText(i18n("Configure"));
     mConfigureViewAction->setStatusTip(i18nc("@info:status", "Configure the view"));
     mConfigureViewAction->setToolTip(i18nc("@info:tooltip", "Configure the current view"));
@@ -615,7 +616,7 @@ void ActionManager::initActions()
     mACollection->addAction(QStringLiteral("show_incidence"), mShowIncidenceAction);
     connect(mShowIncidenceAction, &QAction::triggered, mCalendarView, qOverload<>(&CalendarView::showIncidence));
 
-    mEditIncidenceAction = new QAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("&Edit..."), this);
+    mEditIncidenceAction = new QAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("&Edit…"), this);
     mACollection->addAction(QStringLiteral("edit_incidence"), mEditIncidenceAction);
     connect(mEditIncidenceAction, &QAction::triggered, mCalendarView, qOverload<>(&CalendarView::editIncidence));
 
@@ -624,7 +625,7 @@ void ActionManager::initActions()
     connect(mDeleteIncidenceAction, &QAction::triggered, mCalendarView, qOverload<>(&CalendarView::deleteIncidence));
     mACollection->setDefaultShortcut(mDeleteIncidenceAction, QKeySequence(Qt::Key_Delete));
 
-    action = new QAction(i18n("&Make Sub-to-do Independent"), this);
+    action = new QAction(i18nc("@action", "&Make Sub-to-do Independent"), this);
     mACollection->addAction(QStringLiteral("unsub_todo"), action);
     connect(action, &QAction::triggered, mCalendarView, &CalendarView::todo_unsub);
     action->setEnabled(false);
@@ -636,7 +637,7 @@ void ActionManager::initActions()
     //                                         mACollection, "activate_alarm" );
 
     /************************** SCHEDULE MENU ********************************/
-    mPublishEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")), i18n("&Publish Item Information..."), this);
+    mPublishEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")), i18n("&Publish Item Information…"), this);
     mACollection->addAction(QStringLiteral("schedule_publish"), mPublishEvent);
     connect(mPublishEvent, &QAction::triggered, this, [this](bool) {
         mCalendarView->schedule_publish();
@@ -651,7 +652,7 @@ void ActionManager::initActions()
     mSendInvitation->setEnabled(false);
     connect(mCalendarView, &CalendarView::organizerEventsSelected, mSendInvitation, &QAction::setEnabled);
 
-    mRequestUpdate = new QAction(i18n("Re&quest Update"), this);
+    mRequestUpdate = new QAction(i18nc("@action", "Re&quest Update"), this);
     mACollection->addAction(QStringLiteral("schedule_refresh"), mRequestUpdate);
     connect(mRequestUpdate, &QAction::triggered, this, [this](bool) {
         mCalendarView->schedule_refresh();
@@ -659,7 +660,7 @@ void ActionManager::initActions()
     mRequestUpdate->setEnabled(false);
     connect(mCalendarView, &CalendarView::groupEventsSelected, mRequestUpdate, &QAction::setEnabled);
 
-    mSendCancel = new QAction(i18n("Send &Cancellation to Attendees"), this);
+    mSendCancel = new QAction(i18nc("@action", "Send &Cancellation to Attendees"), this);
     mACollection->addAction(QStringLiteral("schedule_cancel"), mSendCancel);
     connect(mSendCancel, &QAction::triggered, this, [this](bool) {
         mCalendarView->schedule_cancel();
@@ -683,19 +684,19 @@ void ActionManager::initActions()
     mRequestChange->setEnabled(false);
     connect(mCalendarView, &CalendarView::groupEventsSelected, mRequestChange, &QAction::setEnabled);
 
-    action = new QAction(i18n("&Mail Free Busy Information..."), this);
+    action = new QAction(i18nc("@action", "&Mail Free Busy Information…"), this);
     mACollection->addAction(QStringLiteral("mail_freebusy"), action);
     connect(action, &QAction::triggered, mCalendarView, &CalendarView::mailFreeBusy);
     action->setEnabled(true);
 
-    mForwardEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18n("&Send as iCalendar..."), this);
+    mForwardEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18n("&Send as iCalendar…"), this);
     mACollection->addAction(QStringLiteral("schedule_forward"), mForwardEvent);
     connect(mForwardEvent, &QAction::triggered, this, [this](bool) {
         mCalendarView->schedule_forward();
     });
     mForwardEvent->setEnabled(false);
 
-    action = new QAction(i18n("&Upload Free Busy Information"), this);
+    action = new QAction(i18nc("@action", "&Upload Free Busy Information"), this);
     mACollection->addAction(QStringLiteral("upload_freebusy"), action);
     connect(action, &QAction::triggered, mCalendarView, &CalendarView::uploadFreeBusy);
     action->setEnabled(true);
@@ -746,15 +747,15 @@ void ActionManager::initActions()
     mShowMenuBarAction->setChecked(KOPrefs::instance()->showMenuBar());
     toggleMenubar(true);
 
-    action = new QAction(i18n("Configure &Date && Time..."), this);
+    action = new QAction(i18nc("@action", "Configure &Date && Time…"), this);
     mACollection->addAction(QStringLiteral("conf_datetime"), action);
     connect(action, &QAction::triggered, this, &ActionManager::configureDateTime);
 
-    action = new QAction(QIcon::fromTheme(QStringLiteral("view-filter")), i18n("Manage View &Filters..."), this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("view-filter")), i18n("Manage View &Filters…"), this);
     mACollection->addAction(QStringLiteral("edit_filters"), action);
     connect(action, &QAction::triggered, mCalendarView, &CalendarView::editFilters);
 
-    action = new QAction(i18n("Manage T&ags..."), this);
+    action = new QAction(i18nc("@action", "Manage T&ags…"), this);
     mACollection->addAction(QStringLiteral("edit_categories"), action);
     connect(action, &QAction::triggered, mCalendarView->dialogManager(), &KODialogManager::showCategoryEditDialog);
 
@@ -762,7 +763,7 @@ void ActionManager::initActions()
     mACollection->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 
     if (mIsPart) {
-        action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure KOrganizer..."), this);
+        action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure KOrganizer…"), this);
         mACollection->addAction(QStringLiteral("korganizer_configure"), action);
         connect(action, &QAction::triggered, mCalendarView, &CalendarView::edit_options);
         mACollection->addAction(KStandardAction::KeyBindings, QStringLiteral("korganizer_configure_shortcuts"), this, &ActionManager::keyBindings);
@@ -1261,7 +1262,7 @@ protected:
             mShow->setText(i18n("&Show Event"));
         }
         if (mEdit) {
-            mEdit->setText(i18n("&Edit Event..."));
+            mEdit->setText(i18n("&Edit Event…"));
         }
         if (mDelete) {
             mDelete->setText(i18n("&Delete Event"));
@@ -1275,7 +1276,7 @@ protected:
             mShow->setText(i18n("&Show To-do"));
         }
         if (mEdit) {
-            mEdit->setText(i18n("&Edit To-do..."));
+            mEdit->setText(i18n("&Edit To-do…"));
         }
         if (mDelete) {
             mDelete->setText(i18n("&Delete To-do"));
@@ -1300,7 +1301,7 @@ protected:
             mShow->setText(i18n("&Show"));
         }
         if (mEdit) {
-            mEdit->setText(i18n("&Edit..."));
+            mEdit->setText(i18n("&Edit…"));
         }
         if (mDelete) {
             mDelete->setText(i18n("&Delete"));
@@ -1339,7 +1340,7 @@ void ActionManager::processIncidenceSelection(const Akonadi::Item &item, QDate d
     ActionStringsVisitor v;
     if (!v.act(incidence, mShowIncidenceAction, mEditIncidenceAction, mDeleteIncidenceAction)) {
         mShowIncidenceAction->setText(i18n("&Show"));
-        mEditIncidenceAction->setText(i18n("&Edit..."));
+        mEditIncidenceAction->setText(i18n("&Edit…"));
         mDeleteIncidenceAction->setText(i18n("&Delete"));
     }
 }
@@ -1608,7 +1609,7 @@ void ActionManager::updateUndoRedoActions()
         QString nextUndoDescription = history->nextUndoDescription();
         if (nextUndoDescription.length() > 30) {
             nextUndoDescription.truncate(30);
-            nextUndoDescription += QStringLiteral("...");
+            nextUndoDescription += QStringLiteral("…");
         }
         mUndoAction->setText(i18n("Undo: %1", nextUndoDescription));
     } else {
@@ -1621,7 +1622,7 @@ void ActionManager::updateUndoRedoActions()
         QString nextRedoDescription = history->nextRedoDescription();
         if (nextRedoDescription.length() > 30) {
             nextRedoDescription.truncate(30);
-            nextRedoDescription += QStringLiteral("...");
+            nextRedoDescription += QStringLiteral("…");
         }
         mRedoAction->setText(i18n("Redo: %1", nextRedoDescription));
     } else {
@@ -1654,8 +1655,8 @@ void ActionManager::importCalendar(const QUrl &url)
     const int answer = KMessageBox::questionTwoActionsCancel(dialogParent(),
                                                              questionText,
                                                              i18nc("@title:window", "Import Calendar"),
-                                                             KGuiItem(i18n("Merge into existing calendar")),
-                                                             KGuiItem(i18n("Add as new calendar")));
+                                                             KGuiItem(i18nc("@action:button", "Merge into existing calendar")),
+                                                             KGuiItem(i18nc("@action:button", "Add as new calendar")));
 
     switch (answer) {
     case KMessageBox::ButtonCode::PrimaryAction: // merge
